// 
// Copyright (C) 2006, NinjaTrader LLC <www.ninjatrader.com>.
// NinjaTrader reserves the right to modify or overwrite this NinjaScript component with each release.
//

#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Indicator;
using NinjaTrader.Strategy;
#endregion

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{

	[Description("Simple moving average cross over strategy.")]
	public class eabtraderPorcent : Strategy
	{
		#region Variables
		private int		fast	= 10;
		private int		slow	= 25;
		private double stopPorc =5;
		private double profitPorc =5;
		private double accountValue=25000;
		private double CurrentProfit=0;
		
		#endregion


		protected override void Initialize()
		{
			SMA(Fast).Plots[0].Pen.Color = Color.Orange;
			SMA(Slow).Plots[0].Pen.Color = Color.Green;

            Add(SMA(Fast));
            Add(SMA(Slow));

			CalculateOnBarClose	= true;
		}

		protected override void OnBarUpdate()
		{
			if (CurrentBar<slow) return;
			
			CurrentProfit=Performance.AllTrades.TradesPerformance.Currency.CumProfit;
			
			double SLP = StopPorc / 100;
			double PTP = ProfitPorc / 100;
			
			double AccountBalance= AccountValue+CurrentProfit;
			double STopLossCurrency=AccountBalance*SLP;
			double ProfitCurrency=AccountBalance*PTP;
		
			
			SetStopLoss(STopLossCurrency);
			SetProfitTarget(ProfitCurrency);
			
			if (Position.MarketPosition!=MarketPosition.Flat)
			{
			PrintWithTimeStamp("AccountBalance: "+AccountBalance+"    "+"STopLossCurrency: "+STopLossCurrency+"     "+"ProfitCurrency: "+ProfitCurrency);
				
			}
			
			
			if (CrossAbove(SMA(Fast), SMA(Slow), 1))
			    EnterLong();
			else if (CrossBelow(SMA(Fast), SMA(Slow), 1))
			    EnterShort();
		}

		#region Properties
		/// <summary>
		/// </summary>
		[Description("Period for fast MA")]
		[GridCategory("Parameters")]
		public int Fast
		{
			get { return fast; }
			set { fast = Math.Max(1, value); }
		}

		/// <summary>
		/// </summary>
		[Description("Period for slow MA")]
		[GridCategory("Parameters")]
		public int Slow
		{
			get { return slow; }
			set { slow = Math.Max(1, value); }
		}
				[Description("")]
        [Category("Parameters")]
        public  double StopPorc
        {
            get { return stopPorc; }
            set { stopPorc = Math.Max(0, value); }
        }
				[Description("")]
        [Category("Parameters")]
        public  double ProfitPorc
        {
            get { return profitPorc; }
            set { profitPorc = Math.Max(0, value); }
        }
		
						[Description("")]
        [Category("Parameters")]
        public  double AccountValue
        {
            get { return accountValue; }
            set { accountValue = Math.Max(0, value); }
        }
		#endregion
	}
}
